pilas.habilidades.Disparar

Package pilas :: Module habilidades :: Class Disparar |
[hide private]
[frames] | no frames]

# Class Disparar

source code

    object --+
             |
     Habilidad --+
                 |
                Disparar

Known Subclasses:
  - DispararConClick

Establece la habilidad de poder disparar un Actor o un objeto de tipo pilas.municion.Municion.

Instance Methods | [hide private]
__init__(self, receptor, municion=<class 'pilas.actores.proyectil.Bala'>, parametros_municion=`{``}`, grupo_enemigos=`[``]`, cuando_elimina_enemigo=None, frecuencia_de_disparo=10, angulo_salida_disparo=0, offset_disparo=`(`0`,` 0`)`, offset_origen_actor=`(`0`,` 0`)`, cuando_dispara=None, escala=1) Construye la habilidad. | source code
set_frecuencia_de_disparo(self, valor) | source code
get_frecuencia_de_disparo(self) | source code
set_municion(self, valor) | source code
get_municion(self) | source code
definir_colision(self, grupo_enemigos, cuando_elimina_enemigo) | source code
actualizar(self) | source code
_agregar_disparo(self, proyectil) | source code
_eliminar_disparos_innecesarios(self) | source code
_desplazar_proyectil(self, proyectil, offset_x, offset_y) | source code
disparar(self) | source code
eliminar(self) | source code
pulsa_disparar(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| frecuencia_de_disparo Número de disparos por segundo.
| municion Establece el tipo de municion que dispara.
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor, municion=<class 'pilas.actores.proyectil.Bala'>, parametros_municion=`{``}`, grupo_enemigos=`[``]`, cuando_elimina_enemigo=None, frecuencia_de_disparo=10, angulo_salida_disparo=0, offset_disparo=`(`0`,` 0`)`, offset_origen_actor=`(`0`,` 0`)`, cuando_dispara=None, escala=1) (Constructor) | source code
Construye la habilidad. :param municion: Municion o Actor que se disparará. :param grupo_enemigos: Actores que son considerados enemigos y con los que colisionará la munición disparada. :param cuando_elimina_enemigo: Método que será llamado cuando se produzca un impacto con un enemigo. :param frecuencia_de_disparo: El número de disparos por segundo que realizará. :param angulo_salida_disparo: Especifica el angulo por donde saldrá el disparo efectuado por el Actor. :param offset_disparo: Separación en pixeles (x,y) del disparo con respecto al centro del Actor. :param offset_origen_actor: Si el Actor no tiene su origen en el centro, con este parametro podremos colocar correctamente el disparo. :param cuando_dispara: Metodo que será llamado cuando se produzca un disparo. :param escala: Escala de los actores que serán disparados. :example:
    >>> mono = pilas.actores.Mono()
    >>> mono.aprender(pilas.habilidades.Disparar,
    >>>               municion=pilas.actores.proyectil.Bala,
    >>>               grupo_enemigos=enemigos,
    >>>               cuando_elimina_enemigo=eliminar_enemigo)
.. Overrides: object.__init__

### actualizar(self) | source code
Overrides: Habilidad.actualizar

### eliminar(self) | source code
Overrides: Habilidad.eliminar

Property Details | [hide private]

### frecuencia_de_disparo Número de disparos por segundo. Get Method: get_frecuencia_de_disparo(self) Set Method: set_frecuencia_de_disparo(self, valor)

### municion Establece el tipo de municion que dispara. Get Method: get_municion(self) Set Method: set_municion(self, valor)